==> watson_machine_learning_client-1.0.283.tar.gz: watson_machine_learning_client-1.0.283/watson_machine_learning_client/tests/svt/test_ai_functions_from_func_hitting_scoring.py <==
import unittest

from watson_machine_learning_client.log_util import get_logger
from preparation_and_cleaning import *
from models_preparation import *


class TestAIFunction(unittest.TestCase):
    runtime_uid = None
    deployment_uid = None
    function_uid = None
    scoring_url = None
    logger = get_logger(__name__)

    @classmethod
    def setUpClass(self):
        TestAIFunction.logger.info("Service Instance: setting up credentials")

        self.wml_credentials = get_wml_credentials()
        self.client = get_client()

        self.function_name = 'simplest AI function'
        self.deployment_name = "Test deployment"

    def test_01_service_instance_details(self):
        TestAIFunction.logger.info("Check client ...")
        self.assertTrue(self.client.__class__.__name__ == 'WatsonMachineLearningAPIClient')

        TestAIFunction.logger.info("Getting instance details ...")
        details = self.client.service_instance.get_details()
        TestAIFunction.logger.debug(details)

        self.assertTrue("published_models" in str(details))
        self.assertEqual(type(details), dict)

    def test_02_create_ai_function(self):

        self.client.repository.FunctionMetaNames.show()

        function_props = {
            self.client.repository.FunctionMetaNames.NAME: 'simplest AI function',
            self.client.repository.FunctionMetaNames.DESCRIPTION: 'desc',
            self.client.repository.FunctionMetaNames.TAGS: [{"value": "ProjectA", "description": "Functions created for ProjectA"}],
            self.client.repository.FunctionMetaNames.INPUT_DATA_SCHEMA: {
              "type": "struct",
              "fields": [
                {
                  "name": "x",
                  "type": "double",
                  "nullable": False,
                  "metadata": {}
                },
                {
                  "name": "y",
                  "type": "double",
                  "nullable": False,
                  "metadata": {}
                }
              ]
            },
            self.client.repository.FunctionMetaNames.OUTPUT_DATA_SCHEMA: {
              "type": "struct",
              "fields": [
                {
                  "name": "multiplication",
                  "type": "double",
                  "nullable": False,
                  "metadata": {}
                }
              ]
            }
        }

        # create model area

        # create deployment area

        # create model action

        # create deployment action

        def score_wrapper(
                wml_credentials=self.client.wml_credentials,
                modelver_area='7f865b26-f55d-47af-9d11-7fd9692f76ac',
                scoring_url_area='https://us-south.ml.cloud.ibm.com/v3/wml_instances/000263d8-04e0-4060-ad69-fcfe40069018/published_models/0db673e9-1c62-4381-b7de-ef4de0d38b39/deployments/76886441-7656-424a-9060-a0ca770d5a08/online',
                modelver_action='a9816c12-7896-488e-9427-73926f6fa5fd',
                scoring_url_action = 'https://us-south.ml.cloud.ibm.com/v3/wml_instances/000263d8-04e0-4060-ad69-fcfe40069018/published_models/fef7671d-6877-46ae-a13b-617026e494ba/deployments/84872281-f46f-4fd1-afab-4dc6d44bd345/online'
        ):
            def score(payload):
                """AI function with model version.

                Example:
                  {"fields": ["ID", "Gender", "Status", "Children", "Age", "Customer_Status", "Car_Owner", "Customer_Service"],
                   "values": [[2624, 'Male', 'S', 0, 49.27, 'Active', 'No', "Good experience with all the rental co.'s I contacted. I Just called with rental dates and received pricing and selected rental co.", 1]]}
                """
                from watson_machine_learning_client import WatsonMachineLearningAPIClient

                client = WatsonMachineLearningAPIClient(wml_credentials)

                scores_area = client.deployments.score(scoring_url_area, payload)
                scores_action = client.deployments.score(scoring_url_action, payload)

                values = [rec + scores_area['values'][i][slice(15, 17)] + [modelver_area] + scores_action['values'][i][
                    slice(20, 22)] + [modelver_action] for i, rec in enumerate(payload['values'])]

                fields = payload['fields'] + ['Probability_Area', 'Prediction_Area', 'Model_Version_Area'] + [
                    'Probability_Action', 'Prediction_Action', 'Model_Version_Action']

                return {'fields': fields, 'values': values}

            return score

        ai_function_details = self.client.repository.store_function(score_wrapper, function_props)

        TestAIFunction.function_uid = self.client.repository.get_function_uid(ai_function_details)
        function_url = self.client.repository.get_function_url(ai_function_details)
        TestAIFunction.logger.info("AI function ID:" + str(TestAIFunction.function_uid))
        TestAIFunction.logger.info("AI function URL:" + str(function_url))
        self.assertIsNotNone(TestAIFunction.function_uid)
        self.assertIsNotNone(function_url)
        TestAIFunction.runtime_uid = self.client.runtimes.get_uid(ai_function_details)

    def test_03_download_ai_function_content(self):
        try:
            os.remove('test_ai_function.tar.gz')
        except:
            pass

        self.client.repository.download(TestAIFunction.function_uid, filename='test_ai_function.tar.gz')

        try:
            os.remove('test_ai_function.tar.gz')
        except:
            pass

    def test_04_get_details(self):
        details = self.client.repository.get_function_details()
        self.assertTrue(self.function_name in str(details))

        details = self.client.repository.get_function_details(self.function_uid)
        self.assertTrue(self.function_name in str(details))

        details = self.client.repository.get_details()
        self.assertTrue("functions" in details)

        details = self.client.repository.get_details(self.function_uid)
        self.assertTrue(self.function_name in str(details))

    def test_05_list(self):
        self.client.repository.list()

        self.client.repository.list_functions()

    def test_06_create_deployment(self):
        TestAIFunction.logger.info("Create deployment")
        deployment = self.client.deployments.create(artifact_uid=self.function_uid, name=self.deployment_name, asynchronous=False)
        TestAIFunction.logger.debug("Online deployment: " + str(deployment))
        TestAIFunction.scoring_url = self.client.deployments.get_scoring_url(deployment)
        TestAIFunction.logger.debug("Scoring url: {}".format(TestAIFunction.scoring_url))
        TestAIFunction.deployment_uid = self.client.deployments.get_uid(deployment)
        TestAIFunction.logger.debug("Deployment uid: {}".format(TestAIFunction.deployment_uid))
        self.assertTrue("online" in str(deployment))

    def test_07_get_deployment_details(self):
        TestAIFunction.logger.info("Get deployment details")
        deployment_details = self.client.deployments.get_details()
        TestAIFunction.logger.debug("Deployment details: {}".format(deployment_details))
        self.assertTrue(self.deployment_name in str(deployment_details))

    def test_08_score(self):
        sample_payload = {
            "fields": ["ID", "Gender", "Status", "Children", "Age", "Customer_Status", "Car_Owner", "Customer_Service",
                       "Satisfaction"],
            "values": [[2624, 'Male', 'S', 0, 49.27, 'Active', 'No',
                        "Good experience with all the rental co.'s I contacted. I Just called with rental dates and received pricing and selected rental co.",
                        1]]}
        predictions = self.client.deployments.score(TestAIFunction.scoring_url, sample_payload)
        print("Predictions: {}".format(predictions))
        self.assertTrue("values" in str(predictions))

    def test_09_delete_deployment(self):
        TestAIFunction.logger.info("Delete deployment")
        self.client.deployments.delete(TestAIFunction.deployment_uid)

    def test_10_delete_function(self):
        TestAIFunction.logger.info("Delete function")
        self.client.repository.delete(TestAIFunction.function_uid)

    def test_11_delete_runtime(self):
        self.client.runtimes.delete(TestAIFunction.runtime_uid)


if __name__ == '__main__':
    unittest.main()

==> watson_machine_learning_client-1.0.295.tar.gz: watson_machine_learning_client-1.0.295/watson_machine_learning_client/tests/svt/test_ai_functions_from_func_hitting_scoring.py <==
import unittest

from watson_machine_learning_client.log_util import get_logger
from preparation_and_cleaning import *
from models_preparation import *


class TestAIFunction(unittest.TestCase):
    runtime_uid = None
    deployment_uid = None
    function_uid = None
    scoring_url = None
    area_model_uid = None
    recommendation_model_uid = None
    area_deployment_uid = None
    recommendation_deployment_uid = None
    logger = get_logger(__name__)

    @classmethod
    def setUpClass(self):
        TestAIFunction.logger.info("Service Instance: setting up credentials")
        self.recommendation_model_path = os.path.join(os.getcwd(), 'artifacts', 'model_recommendation.tar.gz')
        self.area_model_path = os.path.join(os.getcwd(), 'artifacts', 'model_area.tar.gz')

        self.wml_credentials = get_wml_credentials()
        self.client = get_client()

        self.function_name = 'simplest AI function'
        self.deployment_name = "Test deployment"

    def test_01_service_instance_details(self):
        TestAIFunction.logger.info("Check client ...")
        self.assertTrue(self.client.__class__.__name__ == 'WatsonMachineLearningAPIClient')

        TestAIFunction.logger.info("Getting instance details ...")
        details = self.client.service_instance.get_details()
        TestAIFunction.logger.debug(details)

        self.assertTrue("published_models" in str(details))
        self.assertEqual(type(details), dict)

    def test_02_create_ai_function(self):

        self.client.repository.FunctionMetaNames.show()

        function_props = {
            self.client.repository.FunctionMetaNames.NAME: 'simplest AI function',
            self.client.repository.FunctionMetaNames.DESCRIPTION: 'desc',
            self.client.repository.FunctionMetaNames.TAGS: [{"value": "ProjectA", "description": "Functions created for ProjectA"}],
            self.client.repository.FunctionMetaNames.INPUT_DATA_SCHEMA: {
              "type": "struct",
              "fields": [
                {
                  "name": "x",
                  "type": "double",
                  "nullable": False,
                  "metadata": {}
                },
                {
                  "name": "y",
                  "type": "double",
                  "nullable": False,
                  "metadata": {}
                }
              ]
            },
            self.client.repository.FunctionMetaNames.OUTPUT_DATA_SCHEMA: {
              "type": "struct",
              "fields": [
                {
                  "name": "multiplication",
                  "type": "double",
                  "nullable": False,
                  "metadata": {}
                }
              ]
            }
        }

        from pyspark.sql import SparkSession

        spark = SparkSession.builder.getOrCreate()

        wml_credentials = {
            "username": "61261a0f-df08-4176-a559-5affc3016575",
            "password": "f0ec5f1d-ca3c-4d29-b61c-631a958aa190",
            "instance_id": "e094dca3-9e98-40b0-a084-521b01950dea",
            "url": "https://us-south.ml.test.cloud.ibm.com"
        }

        from watson_machine_learning_client import WatsonMachineLearningAPIClient

        client2 = WatsonMachineLearningAPIClient(wml_credentials)

        recommendation_model = client2.repository.load('357c06cd-5075-430e-9af7-d44e8bbe7fdf')
        area_model = client2.repository.load('b973ccfa-36e3-4631-af71-754ee0de1b74')

        # create model area
        area_model_details = self.client.repository.store_model(area_model, {
            self.client.repository.ModelMetaNames.NAME: "area_model",
            self.client.repository.ModelMetaNames.FRAMEWORK_NAME: "spss-modeler",
            self.client.repository.ModelMetaNames.FRAMEWORK_VERSION: "18.0"
        })
        TestAIFunction.area_model_uid = self.client.repository.get_model_uid(area_model_details)

        # create deployment area
        area_deployment_details = self.client.deployments.create(TestAIFunction.area_model_uid, 'area_deployment')
        TestAIFunction.area_deployment_uid = self.client.deployments.get_uid(area_deployment_details)
        area_scoring_url = self.client.deployments.get_scoring_url(area_deployment_details)

        # create model action
        recommendation_model_details = self.client.repository.store_model(recommendation_model, {
            self.client.repository.ModelMetaNames.NAME: "recommendation_model",
            self.client.repository.ModelMetaNames.FRAMEWORK_NAME: "spss-modeler",
            self.client.repository.ModelMetaNames.FRAMEWORK_VERSION: "18.0"
        })
        TestAIFunction.recommendation_model_uid = self.client.repository.get_model_uid(recommendation_model_details)

        # create deployment action
        recommendation_deployment_details = self.client.deployments.create(TestAIFunction.recommendation_model_uid, 'recommendation_deployment')
        TestAIFunction.recommendation_deployment_uid = self.client.deployments.get_uid(recommendation_deployment_details)
        recommendation_scoring_url = self.client.deployments.get_scoring_url(recommendation_deployment_details)

        def score_wrapper(
                wml_credentials=self.client.wml_credentials,
                modelver_area='ver1',
                scoring_url_area=area_scoring_url,
                modelver_action='ver2',
                scoring_url_action = recommendation_scoring_url
        ):
            def score(payload):
                """AI function with model version.

                Example:
                  {"fields": ["ID", "Gender", "Status", "Children", "Age", "Customer_Status", "Car_Owner", "Customer_Service"],
                   "values": [[2624, 'Male', 'S', 0, 49.27, 'Active', 'No', "Good experience with all the rental co.'s I contacted. I Just called with rental dates and received pricing and selected rental co.", 1]]}
                """
                from watson_machine_learning_client import WatsonMachineLearningAPIClient

                client = WatsonMachineLearningAPIClient(wml_credentials)

                scores_area = client.deployments.score(scoring_url_area, payload)
                scores_action = client.deployments.score(scoring_url_action, payload)

                values = [rec + scores_area['values'][i][slice(15, 17)] + [modelver_area] + scores_action['values'][i][
                    slice(20, 22)] + [modelver_action] for i, rec in enumerate(payload['values'])]

                fields = payload['fields'] + ['Probability_Area', 'Prediction_Area', 'Model_Version_Area'] + [
                    'Probability_Action', 'Prediction_Action', 'Model_Version_Action']

                return {'fields': fields, 'values': values}

            return score

        ai_function_details = self.client.repository.store_function(score_wrapper, function_props)

        TestAIFunction.function_uid = self.client.repository.get_function_uid(ai_function_details)
        function_url = self.client.repository.get_function_url(ai_function_details)
        TestAIFunction.logger.info("AI function ID:" + str(TestAIFunction.function_uid))
        TestAIFunction.logger.info("AI function URL:" + str(function_url))
        self.assertIsNotNone(TestAIFunction.function_uid)
        self.assertIsNotNone(function_url)
        TestAIFunction.runtime_uid = self.client.runtimes.get_uid(ai_function_details)

    def test_03_download_ai_function_content(self):
        try:
            os.remove('test_ai_function.tar.gz')
        except:
            pass

        self.client.repository.download(TestAIFunction.function_uid, filename='test_ai_function.tar.gz')

        try:
            os.remove('test_ai_function.tar.gz')
        except:
            pass

    def test_04_get_details(self):
        details = self.client.repository.get_function_details()
        self.assertTrue(self.function_name in str(details))

        details = self.client.repository.get_function_details(self.function_uid)
        self.assertTrue(self.function_name in str(details))

        details = self.client.repository.get_details()
        self.assertTrue("functions" in details)

        details = self.client.repository.get_details(self.function_uid)
        self.assertTrue(self.function_name in str(details))

    def test_05_list(self):
        self.client.repository.list()

        self.client.repository.list_functions()

    def test_06_create_deployment(self):
        TestAIFunction.logger.info("Create deployment")
        deployment = self.client.deployments.create(artifact_uid=self.function_uid, name=self.deployment_name, asynchronous=False)
        TestAIFunction.logger.debug("Online deployment: " + str(deployment))
        TestAIFunction.scoring_url = self.client.deployments.get_scoring_url(deployment)
        TestAIFunction.logger.debug("Scoring url: {}".format(TestAIFunction.scoring_url))
        TestAIFunction.deployment_uid = self.client.deployments.get_uid(deployment)
        TestAIFunction.logger.debug("Deployment uid: {}".format(TestAIFunction.deployment_uid))
        self.assertTrue("online" in str(deployment))

    def test_07_get_deployment_details(self):
        TestAIFunction.logger.info("Get deployment details")
        deployment_details = self.client.deployments.get_details()
        TestAIFunction.logger.debug("Deployment details: {}".format(deployment_details))
        self.assertTrue(self.deployment_name in str(deployment_details))

    def test_08_score(self):
        sample_payload = {
            "fields": ["ID", "Gender", "Status", "Children", "Age", "Customer_Status", "Car_Owner", "Customer_Service",
                       "Satisfaction"],
            "values": [[2624, 'Male', 'S', 0, 49.27, 'Active', 'No',
                        "Good experience with all the rental co.'s I contacted. I Just called with rental dates and received pricing and selected rental co.",
                        1]]}
        predictions = self.client.deployments.score(TestAIFunction.scoring_url, sample_payload)
        print("Predictions: {}".format(predictions))
        self.assertTrue("values" in str(predictions))

    def test_09_delete_deployment(self):
        TestAIFunction.logger.info("Delete deployment")
        self.client.deployments.delete(TestAIFunction.deployment_uid)

    def test_10_delete_function(self):
        TestAIFunction.logger.info("Delete function")
        self.client.repository.delete(TestAIFunction.function_uid)

    def test_11_delete_runtime(self):
        self.client.runtimes.delete(TestAIFunction.runtime_uid)

    def test_12_clean(self):
        self.client.repository.delete(TestAIFunction.area_model_uid)
        self.client.repository.delete(TestAIFunction.recommendation_model_uid)
        self.client.repository.delete(TestAIFunction.area_deployment_uid)
        self.client.repository.delete(TestAIFunction.recommendation_deployment_uid)


if __name__ == '__main__':
    unittest.main()
